local T, C, L, _ = unpack(select(2, ...))
if C.skins.blizzard_frames ~= true then return end

----------------------------------------------------------------------------------------
--	Quest skin
----------------------------------------------------------------------------------------
local function LoadSkin()
	QuestFrame:CreateBackdrop("Transparent")
	QuestFrame.backdrop:SetPoint("TOPLEFT", 10, -12)
	QuestFrame.backdrop:SetPoint("BOTTOMRIGHT", -32, 76)

	QuestFrameNpcNameText:ClearAllPoints()
	QuestFrameNpcNameText:SetPoint("TOP", QuestFrame.backdrop, "TOP", 0, -6)

	T.SkinCloseButton(QuestFrameCloseButton, QuestFrame.backdrop)

	local ScrollFrames = {
		"QuestDetailScrollFrame",
		"QuestRewardScrollFrame",
		"QuestProgressScrollFrame",
		"QuestGreetingScrollFrame",
	}

	for _, object in pairs(ScrollFrames) do
		_G[object]:ClearAllPoints()
		_G[object]:SetPoint("TOP", QuestFrame.backdrop, -6, -30)
		_G[object]:SetHeight(362)
	end

	local QuestStrip = {
		"QuestFrame",
		"QuestFrameDetailPanel",
		"QuestDetailScrollFrame",
		"QuestDetailScrollChildFrame",
		"QuestRewardScrollFrame",
		"QuestRewardScrollChildFrame",
		"QuestProgressScrollFrame",
		"QuestGreetingScrollFrame",
		"QuestFrameProgressPanel",
		"QuestFrameRewardPanel",
	}

	for _, object in pairs(QuestStrip) do
		_G[object]:StripTextures(true)
	end

	QuestFrameDetailPanel:SetPoint("TOPLEFT", -5, -12)
	QuestFrameDetailPanel:SetPoint("BOTTOMRIGHT", 0, 76)
	QuestFrameProgressPanel:SetPoint("TOPLEFT", -5, -12)
	QuestFrameProgressPanel:SetPoint("BOTTOMRIGHT", 0, 76)

	local LeftQuestButtons = {
		"QuestFrameAcceptButton",
		"QuestFrameCompleteButton",
		"QuestFrameCompleteQuestButton",
	}

	local RightQuestButtons = {
		"QuestFrameDeclineButton",
		"QuestFrameGoodbyeButton",
		"QuestFrameCancelButton",
	}

	for _, button in pairs(LeftQuestButtons) do
		_G[button]:SkinButton()
		_G[button]:SetPoint("BOTTOMLEFT", QuestFrame.backdrop, "BOTTOMLEFT", 4, 4)
	end

	for _, button in pairs(RightQuestButtons) do
		_G[button]:SkinButton()
		_G[button]:SetPoint("BOTTOMRIGHT", QuestFrame.backdrop, "BOTTOMRIGHT", -4, 4)
	end

	local ScrollBars = {
		"QuestDetailScrollFrameScrollBar",
		"QuestProgressScrollFrameScrollBar",
		"QuestRewardScrollFrameScrollBar",
		"QuestGreetingScrollFrameScrollBar",
		"QuestNPCModelTextScrollFrameScrollBar",
	}

	for _, scrollbar in pairs(ScrollBars) do
		T.SkinScrollBar(_G[scrollbar])
	end

	local function HookTextColor_Yellow(self, r, g, b)
		if r ~= 1 or g ~= .8 or b ~= 0 then
			self:SetTextColor(1, .8, 0)
		end
	end

	local function SetTextColor_Yellow(font)
		font:SetShadowColor(0, 0, 0, 0)
		font:SetTextColor(1, .8, 0)
		hooksecurefunc(font, "SetTextColor", HookTextColor_Yellow)
	end

	local function HookTextColor_White(self, r, g, b)
		if r ~= 1 or g ~= 1 or b ~= 1 then
			self:SetTextColor(1, 1, 1)
		end
	end

	local function SetTextColor_White(font)
		font:SetShadowColor(0, 0, 0)
		font:SetTextColor(1, 1, 1)
		hooksecurefunc(font, "SetTextColor", HookTextColor_White)
	end

		-- Change text colors
	hooksecurefunc(QuestInfoRequiredMoneyText, "SetTextColor", function(self, r)
		if r == 0 then
			self:SetTextColor(.8, .8, .8)
		elseif r == .2 then
			self:SetTextColor(1, 1, 1)
		end
	end)

	local yellowish = {
		QuestInfoTitleHeader,
		QuestInfoDescriptionHeader,
		QuestInfoObjectivesHeader,
		QuestInfoRewardsFrame.Header,
		QuestInfoQuestType,
	}
	for _, font in pairs(yellowish) do
		SetTextColor_Yellow(font)
	end

	local whitish = {
		QuestInfoDescriptionText,
		QuestInfoObjectivesText,
		QuestInfoGroupSize,
		QuestInfoRewardText,
		QuestInfoSpellObjectiveLearnLabel,
		QuestInfoRewardsFrame.ItemChooseText,
		QuestInfoRewardsFrame.ItemReceiveText,
		QuestInfoRewardsFrame.PlayerTitleText,
		QuestInfoRewardsFrame.XPFrame.ReceiveText,
		QuestInfoRewardsFrameHonorReceiveText,
		QuestInfoRewardsFrameReceiveText,
		QuestInfoTalentFrame.ReceiveText,
	}
	for _, font in pairs(whitish) do
		SetTextColor_White(font)
	end

	local function SkinReward(button, mapReward)
		if button.NameFrame then button.NameFrame:Hide() end
		if button.CircleBackground then button.CircleBackground:Hide() end
		if button.CircleBackgroundGlow then button.CircleBackgroundGlow:Hide() end
		if button.ValueText then button.ValueText:SetPoint("BOTTOMRIGHT", button.Icon, 0, 0) end
		if button.IconBorder then button.IconBorder:SetAlpha(0) end
		button.Icon:SetTexCoord(0.1, 0.9, 0.1, 0.9)
		button:CreateBackdrop("Default")
		button.backdrop:ClearAllPoints()
		button.backdrop:SetPoint("TOPLEFT", button, -2, 1)
		button.backdrop:SetPoint("BOTTOMRIGHT", button, -4, 1)
		if mapReward then
			button.Icon:SetSize(26, 26)
		end
	end

	local function SkinQualityBorder(self, index)
		local buttonType = self:GetParent().type
		local objectType = self:GetParent().objectType
		local quality

		if objectType == "item" then
			if QuestInfoFrame.questLog then
				quality = select(4, GetQuestLogChoiceInfo(index))
			else
				quality = select(4, GetQuestItemInfo(buttonType, index))
			end
		elseif objectType == "currency" then
			if QuestInfoFrame.questLog then						
				quality = select(5, GetQuestLogRewardCurrencyInfo(index))
			else
				quality = select(4, GetQuestCurrencyInfo("reward", index))
			end
		end
		local r, g, b = GetItemQualityColor(quality or 4)

		return r, g, b
	end

	hooksecurefunc("QuestInfo_GetRewardButton", function(rewardsFrame, index)
		local button = rewardsFrame.RewardButtons[index]
		if not button.backdrop then
			SkinReward(button, rewardsFrame == MapQuestInfoRewardsFrame)
			hooksecurefunc(button.IconBorder, "SetVertexColor", function(self, ar, ag, ab)
				local r, g, b = SkinQualityBorder(self, index)
				if r ~= 0.65882 and g ~= 0.65882 and b ~= 0.65882 then
					self:GetParent().Name:SetTextColor(ar, ag, ab)
					self:GetParent().backdrop:SetBackdropBorderColor(ar, ag, ab)
				else
					self:GetParent().Name:SetTextColor(r, g, b)
					self:GetParent().backdrop:SetBackdropBorderColor(r, g, b)

				end
				self:SetTexture("")
			end)

			hooksecurefunc(button.IconBorder, "Hide", function(self)
				local r, g, b = SkinQualityBorder(self, index)
				self:GetParent().Name:SetTextColor(r, g, b)
				self:GetParent().backdrop:SetBackdropBorderColor(r, g, b)
			end)
		end
	end)

	QuestInfoItemHighlight:StripTextures()
	QuestInfoItemHighlight:SetTemplate("Default")
	QuestInfoItemHighlight:SetBackdropBorderColor(0, 0, 0)
	QuestInfoItemHighlight:SetBackdropColor(1, 1, 0, 0.3)

	hooksecurefunc("QuestInfoItem_OnClick", function(self)
		if self.type == "reward" then return end
		QuestInfoItemHighlight:ClearAllPoints()
		QuestInfoItemHighlight:SetPoint("TOPLEFT", self, "TOPLEFT", -1, 0)
		QuestInfoItemHighlight:SetPoint("BOTTOMRIGHT", self, "BOTTOMRIGHT", -5, 2)
	end)

	local function UpdateProgressItemQuality(self)
		local button = self.__owner
		local index = button:GetID()
		local buttonType = button.type
		local objectType = button.objectType

		local quality
		if objectType == "item" then
			quality = select(4, GetQuestItemInfo(buttonType, index))
		elseif objectType == "currency" then
			quality = select(4, GetQuestCurrencyInfo(buttonType, index))
		end

		local r, g, b = GetItemQualityColor(quality)
		button.backdrop:SetBackdropBorderColor(r, g, b)
	end

	for i = 1, 6 do
		local button = _G["QuestProgressItem"..i]
		local texture = _G["QuestProgressItem"..i.."IconTexture"]
		local icon = button.Icon
		icon.__owner = button

		if button.NameFrame then button.NameFrame:Hide() end
		button.Name:SetFont(C.media.normal_font, 12)

		button:CreateBackdrop("Default")
		button.backdrop:ClearAllPoints()
		button.backdrop:SetPoint("TOPLEFT", texture, -2, 2)
		button.backdrop:SetPoint("BOTTOMRIGHT", texture, 2, -2)

		texture:SetTexCoord(0.1, 0.9, 0.1, 0.9)

		hooksecurefunc(button.Icon, "SetTexture", UpdateProgressItemQuality)
	end

	hooksecurefunc("QuestFrameProgressItems_Update", function()
		QuestProgressTitleText:SetTextColor(1, 0.8, 0)
		QuestProgressTitleText:SetShadowColor(0, 0, 0)
		QuestProgressText:SetTextColor(1, 1, 1)
		QuestProgressRequiredItemsText:SetTextColor(1, 0.8, 0)
		QuestProgressRequiredItemsText:SetShadowColor(0, 0, 0)
		QuestProgressRequiredMoneyText:SetTextColor(1, 0.8, 0)
	end)

	-- QuestGreeting
	local function UpdateGreetingPanel()
		QuestFrameGreetingPanel:StripTextures()
		QuestFrameGreetingGoodbyeButton:SkinButton()
		QuestFrameGreetingGoodbyeButton:SetPoint("BOTTOMRIGHT", QuestFrame.backdrop, "BOTTOMRIGHT", -4, 4)
		GreetingText:SetTextColor(1, 1, 1)
		CurrentQuestsText:SetTextColor(1, 0.8, 0)
		AvailableQuestsText:SetTextColor(1, 0.8, 0)
		QuestGreetingFrameHorizontalBreak:Kill()

		for i = 1, MAX_NUM_QUESTS do
			local button = _G["QuestTitleButton"..i]

			if button:GetFontString() then
				if button:GetFontString():GetText() and button:GetFontString():GetText():find("|cff000000") then
					button:GetFontString():SetText(string.gsub(button:GetFontString():GetText(), "|cff000000", "|cffFFFF00"))
				end
			end
		end
	end

	QuestFrameGreetingPanel:HookScript("OnShow", UpdateGreetingPanel)
	hooksecurefunc("QuestFrameGreetingPanel_OnShow", UpdateGreetingPanel)
end

tinsert(T.SkinFuncs["ShestakUI"], LoadSkin)
