local T, C, L, _ = unpack(select(2, ...))
if C.skins.meetinghorn ~= true then return end

----------------------------------------------------------------------------------------
--	MeetingHorn skin
----------------------------------------------------------------------------------------
if IsAddOnLoaded("MeetingHorn") then
	local MeetingHorn = LibStub("AceAddon-3.0"):GetAddon("MeetingHorn", true)
	if not MeetingHorn then return end

	local mainFrame = _G.MeetingHornMainPanel or MeetingHorn.MainPanel
	if not mainFrame then return end
	mainFrame:StripTextures()
	mainFrame:SetTemplate("Transparent")
	mainFrame.PortraitFrame:SetAlpha(0)
	mainFrame.portrait:SetAlpha(0)

	local function reskinDropDown(dropdown)
		dropdown:StripTextures()
		dropdown:SetHeight(20)
		local down = dropdown.MenuButton
		down:ClearAllPoints()
		down:SetPoint("RIGHT", 0, 0)
		T.SkinNextPrevButton(down)
		down:SetSize(20, 20)
		
		dropdown:CreateBackdrop("Overlay")
	end

	local function reskinQRTooltip(self)
		self:StripTextures()
		self:CreateBackdrop("Default")
		T.SkinCloseButton(self.Close)
		self.Close:SetHitRectInsets(0, 0, 0, 0)

		if self.Image then
			self.Image:SetAlpha(1)
		end
	end

	local imageFrameStyled
	local function reskinImageFrame(self)
		if imageFrameStyled then return end

		for _, child in pairs {self:GetChildren()} do
			if child:GetObjectType() == "Frame" and child.Image and child.Close then
				reskinQRTooltip(child)
				imageFrameStyled = true
				break
			end
		end
	end

	local function reskinHeader(header)
		for i = 4, 18 do
			select(i, header.Button:GetRegions()):SetTexture("")
		end
		header.Button:SkinButton(true)
		header.Button.Title:SetTextColor(1, 1, 1)
		header.Button.Title.SetTextColor = T.Dummy
		header.Button.ExpandedIcon:SetWidth(20)
		header.Button.ExpandedIcon.SetTextColor = T.Dummy

		header.Overview:StripTextures()
		header.Overview.Text:SetTextColor(1, 1, 1)
		header.Overview.Text.SetTextColor = T.Dummy
	end

	local function reskinSummary(summary)
		summary.Title:StripTextures()
		summary.Title.Text:SetTextColor(1, 1, 1)
		summary.Title.Text.SetTextColor = T.Dummy
		summary.Overview.Text:SetTextColor(1, 1, 1)
		summary.Overview.Text.SetTextColor = T.Dummy
	end

	local function reskinItemButton(button)
		button:SetSize(34, 34)
		button.icon:SetAlpha(1)
		button.icon:SkinIcon(true)
	end

	local function strToPath(str)
		local path = {}
		for v in string.gmatch(str, "([^%.]+)") do 
			table.insert(path, v)
		end
		return path
	end

	local function getValue(pathStr, tbl)
		local keys = strToPath(pathStr) 
		local value
		for _, key in pairs(keys) do
			value = value and value[key] or tbl[key]
		end
		return value
	end

	for k, tab in ipairs(mainFrame.Tabs) do
		if k == 1 then
			local relF, parent, relT, x, y = tab:GetPoint()
			tab:SetPoint(relF, parent, relT, x, y - 1)
		end

		tab.Text:SetPoint("TOP", tab, 0, -3)
		tab:StripTextures()		
		local a, b = tab:GetSize()
		tab:SetSize(a, b - 8)
		T.SkinTab(tab)
	end

	local Dropdowns = {
		"Browser.Activity",
		"Browser.Mode",
		"Browser.Quick",
		"Manage.Creator.Activity",
		"Manage.Creator.Mode",
		"Recent.Instance",
		"Encounter.Instance",
		"Challenge.Left.Groups",
	}

	local Headers = {
		"Browser",
		"Manage.Applicant",
	}

	local ScrollBars = {
		"Browser.ActivityList.scrollBar",
		"Manage.Applicant.ApplicantList.scrollBar",
		"Options.Filters.FilterList.scrollBar",
		"FeedBack.EditBox.ScrollFrame.ScrollBar",
		"Manage.Creator.Comment.ScrollFrame.ScrollBar",
		"Manage.Chat.ChatFrame.scrollBar",
		"Quest.Body.Quests.scrollBar",
		"Recent.Members.scrollBar",
	}

	local Panels = {
		"Browser.ActivityList",
		"Manage.Creator",
		"Manage.Chat.ChatBg",
		"Manage.Creator.Comment",
		"Manage.Applicant",
		"Help",
		"Options.Options",
		"Options.Filters",
		"Recent.Left",
		"Recent.Right",
		"Encounter.BossList",
		"Encounter.Panel1",
		"Encounter.Panel2",
	}

	local Buttons = {
		"Browser.Reset",
		"Browser.Refresh",
		"Manage.Creator.CreateButton",
		"Manage.Creator.CloseButton",
		"Manage.Creator.RecruitButton",
		"Options.Filters.Add",
		"Options.Filters.Import",
		"Options.Filters.Export",
		"FeedBack.AcceptButton",
		"FeedBack.CancelButton",
		"Recent.Invite",
	}

	for _, v in pairs(Dropdowns) do
		local dropdown = getValue(v, mainFrame)
		if dropdown then
			reskinDropDown(dropdown)
		end
	end

	for _, v in pairs(Headers) do
		local headerParent = getValue(v, mainFrame)
		if headerParent then
			local index = 1
			local header = headerParent["Header"..index]
			while header do
				T.ChangeSize(header, -2, 0)
				T.ChangePoint(header, 2, 0)
				header:DisableDrawLayer("BACKGROUND")
				header:SkinButton(true)
				header:SetHighlightTexture(C.media.blank)
				local hl = header:GetHighlightTexture()
				hl:SetVertexColor(0.1, 0.1, 0.1, 1)
				hl:SetInside()
				index = index + 1
				header = headerParent["Header"..index]
			end
		end
	end

	for _, v in pairs(ScrollBars) do
		local scrollBar = getValue(v, mainFrame)
		if scrollBar then
			T.SkinScrollBar(scrollBar)
		end
	end

	mainFrame.FeedBack.EditBox:StripTextures()

	for _, v in pairs(Panels) do
		local panel = getValue(v, mainFrame)
		if panel then
			panel:StripTextures()
			panel:CreateBackdrop("Overlay")
			panel.backdrop:SetPoint("TOPLEFT", 4, 2)
			panel.backdrop:SetPoint("BOTTOMRIGHT", 0, -1)
		end
	end

	for _, v in pairs(Buttons) do
		local button = getValue(v, mainFrame)
		if button then
			button:SkinButton(true)
			if button.LeftSeparator then button.LeftSeparator:SetAlpha(0) end
			if button.RightSeparator then button.RightSeparator:SetAlpha(0) end
		end
	end

	local input = getValue("Browser.Input", mainFrame)
	if input then
		T.SkinEditBox(input)
	end

	local FilterInputBoxButtons = {mainFrame.Options.Filters.FilterInputBox:GetChildren()}
	for _, button in pairs(FilterInputBoxButtons) do
		if button:IsObjectType("Button") and button ~= mainFrame.Options.Filters.FilterInputBox.CheckBox then
			button:SkinButton(true)
		end
	end

	T.SkinCheckBox(mainFrame.Options.Filters.FilterInputBox.CheckBox)

	local MainPanelButtons = {mainFrame:GetChildren()}
	for _, button in pairs(MainPanelButtons) do
		if button.AcceptButton then
			button.AcceptButton:SkinButton(true)
		end
		if button.CancelButton then
			button.CancelButton:SkinButton(true)
		end
		if button.EditBox then
			button.EditBox:StripTextures()
			button.EditBox:CreateBackdrop("Overlay")
		end
	end

	local ListView = MeetingHorn:GetClass("UI.ListView")
	hooksecurefunc(ListView, "GetButton", function(self, index)
		local button = self._buttons[index]
		if button and not button.styled then
			button:StripTextures()
			button:SetHighlightTexture(C.media.blank)
			local hl = button:GetHighlightTexture()
			hl:SetVertexColor(0.1, 0.1, 0.1, 1)
			hl:SetInside()

			if button.Icon then
				button.Icon:SetAlpha(1)
			end

			if button.Signup then
				button.Signup:SkinButton(true)
				button.Signup:SetSize(60, 20)
			end

			if button.QRIcon then
				button.QRIcon:HookScript("PostClick", function()
					local tooltip = mainFrame.Browser and mainFrame.Browser.QRTooltip
					if tooltip and not tooltip.styled then
						reskinQRTooltip(tooltip)
						tooltip.styled = true
					end
				end)
			end

			button.styled = true
		end
	end)

	-- Browser
	local Browser = mainFrame.Browser
	if Browser then
		Browser:StripTextures()
		for _, key in ipairs({"ApplyLeaderBtn", "RechargeBtn",}) do
			local bu = Browser[key]
			if bu then
				bu:SkinButton(true)
				bu:HookScript("PostClick", reskinImageFrame)
			end
		end

		local progressBar = Browser.ProgressBar
		if progressBar then
			progressBar:StripTextures()
			progressBar:SetStatusBarTexture(C.media.texture)
			progressBar:DisableDrawLayer("BACKGROUND")
			progressBar:CreateBackdrop("Default")
		end
	end	


	-- Encounter
	local Encounter = mainFrame.Encounter
	if Encounter then
		Encounter:StripTextures()
		Encounter.ZoneButton:StripTextures()
		Encounter.ZoneButton:SkinButton(true)

		T.SkinScrollBar(Encounter.BossList.scrollBar)
		Encounter.BossList.scrollBar.trackBG:SetAlpha(0)
		T.SkinScrollBar(Encounter.Panel1.ScrollBar)
		T.SkinScrollBar(Encounter.Panel2.ScrollBar)

		Encounter.BossTitle:SetTextColor(1, 1, 1)
		Encounter.Panel1.Overview.Text:SetTextColor(1, 1, 1)
		Encounter.Panel2.Overview.Text:SetTextColor(1, 1, 1)
		T.SkinEditBox(Encounter.Panel3.Url)

		for i, tab in ipairs(Encounter.Tabs) do
			tab:CreateBackdrop("Default")
			tab.backdrop:SetPoint("TOPLEFT", 12, -4)
			tab.backdrop:SetPoint("BOTTOMRIGHT", -5, 4)
			tab:SetNormalTexture("")
			tab:SetPushedTexture("")
			tab:SetDisabledTexture("")

			if i == 1 then
				tab:SetPoint("TOPLEFT", Encounter, "TOPRIGHT", -4, -35)
			else
				tab:SetPoint("TOPLEFT", Encounter.Tabs[i-1], "BOTTOMLEFT", 0, 6)
			end
		end

		local LookFall = Encounter.LookFall
		if LookFall then
			LookFall:HookScript("PostClick", reskinImageFrame)
		end
	end

	local EncounterInfo = MeetingHorn:GetClass("UI.EncounterInfo")
	local origEncounterInfoCreate = EncounterInfo.Create
	EncounterInfo.Create = function(self, parent)
		local header = origEncounterInfoCreate(self, parent)
		reskinHeader(header)
		return header
	end

	local EncounterInfoSummary = MeetingHorn:GetClass("UI.EncounterInfoSummary")
	local origEncounterInfoSummaryCreate = EncounterInfoSummary.Create
	EncounterInfoSummary.Create = function(self, parent)
		local summary = origEncounterInfoSummaryCreate(self, parent)
		reskinSummary(summary)
		return summary
	end

	-- Challenge
	local Challenge = mainFrame.Challenge
	if Challenge then
		Challenge.Left:StripTextures()
		Challenge.Summary:StripTextures()
		Challenge.Summary:CreateBackdrop("Default")

		local Body = Challenge.Body
		Body:DisableDrawLayer("BORDER")
		Body:CreateBackdrop("Default")
		Body.WebButton:SkinButton(true)
		Body.UpdateButton:SkinButton(true)
		Body.Reward.Exchange:SkinButton(true)

		for i = 1, Body.Reward:GetNumRegions() do
			local region = select(i, Body.Reward:GetRegions())
			if region and region.IsObjectType and region:IsObjectType("FontString") then
				region:SetTextColor(1, 1, 1)
			end
		end

		local progressBar = Body.ProgressBar
		progressBar:StripTextures()
		progressBar:SetStatusBarTexture(C.media.texture)
		progressBar:DisableDrawLayer("BACKGROUND")
		progressBar:CreateBackdrop("Default")

		local UIChallenge = MeetingHorn:GetClass("UI.Challenge")
		hooksecurefunc(UIChallenge, "GetChallengeButton", function(self, i)
			local button = self.challengeButtons[i]
			if button and not button.styled then
				button.bg:SetAlpha(0)
				button:SkinButton(true)
				button.styled = true
			end
		end)
	end

	-- Quest
	local Quest = mainFrame.Quest
	if Quest then
		local Body = Quest.Body
		if Body then
			Body:StripTextures()
			Body:CreateBackdrop("Overlay")
			if Body.Refresh then Body.Refresh:SkinButton(true) end
		end

		local Summary = Quest.Summary
		if Summary then
			Summary:StripTextures()
			Summary:CreateBackdrop("Overlay")

			for _, child in pairs {Summary:GetChildren()} do
				if child.ScrollBar then
					T.SkinScrollBar(child.ScrollBar)
					break
				end
			end
		end
	end

	-- QuestItem
	local QuestItem = MeetingHorn:GetClass("UI.QuestItem")
	if QuestItem then
		hooksecurefunc(QuestItem, "SetQuest", function(self)
			if not self.itemStyled then
				self:StripTextures()
				self:SetTemplate("Overlay")

				if self.Reward then
					self.Reward:SkinButton(true)
				end

				for index, item in ipairs(self.Items) do
					local r, g, b = item.IconBorder:GetVertexColor()
					reskinItemButton(item)
					item.icon.b:SetBackdropBorderColor(r, g, b)

					if index > 1 then
						item:ClearAllPoints()
						item:SetPoint("LEFT", self.Items[index-1], "RIGHT", 6, 0)
					end
				end

				self.itemStyled = true
			end
		end)
	end

	-- GoodLeader
	local GoodLeader = mainFrame.GoodLeader
	if GoodLeader then
		for _, v in ipairs({"First.Footer", "First.Header", "First.Header.Search", "First.Inset", "Result.Info", "Result.Raids", "Result.Score"}) do
			local subFrame = getValue(v, GoodLeader)
			if subFrame then
				subFrame:StripTextures()
				subFrame:CreateBackdrop("Overlay")

				if v == "First.Header" then
					local ApplyLeaderBtn = subFrame.ApplyLeaderBtn
					if ApplyLeaderBtn then
						ApplyLeaderBtn:SkinButton(true)
						ApplyLeaderBtn:HookScript("PostClick", reskinImageFrame)
					end
				end
			end
		end

		local function HideBackdrop(frame)
			if frame.NineSlice then frame.NineSlice:SetAlpha(0) end
			if frame.SetBackdrop then frame:SetBackdrop(nil) end
		end

		local instances = GoodLeader.Result.Raids.instances
		if instances then
			for _, button in ipairs(instances) do
				HideBackdrop(button)
				button.Image:SkinIcon()
			end
		end
	end

	local GradePanel = MeetingHorn:GetClass("UI.GradePanel")
	if GradePanel then
		hooksecurefunc(GradePanel, "OnShow", function(self)
			if not self.styled then
				self:StripTextures()
				self.Logo:SetAlpha(1)
				self:CreateBackdrop("Transparent")

				self.QrCodeFrame:StripTextures()
				self.QrCodeFrame:CreateBackdrop("Default")

				self.Commit:SkinButton(true)
				self.Cancel:SkinButton(true)
				T.ChangePoint(self.Commit, -2, 0)
				T.ChangePoint(self.Cancel, 4, 0)

				self.styled = true
			end
		end)
	end

	-- Announcement
	local Announcement = mainFrame.Announcement
	if Announcement then
		local loading = Announcement.loading
		if loading then
			loading:StripTextures()
			loading:SetTemplate("Transparent")
		end

		local container = Announcement.container
		if container then
			for _, region in pairs {container:GetRegions()} do
				if region:GetObjectType() == "FontString" then
					region:SetTextColor(1, 1, 1)
				end
			end
		end
	end

	-- MissionGuidance
	local MissionGuidance = mainFrame.MissionGuidance
	if MissionGuidance then
		MissionGuidance:StripTextures()
		MissionGuidance:CreateBackdrop("Overlay")
		T.SkinScrollBar(MissionGuidance.MissionGuidanceScrollFrame.ScrollBar)
	end

	if IsAddOnLoaded("tdInspect") then  -- Credit: tdUI
		local tdInspect = LibStub("AceAddon-3.0"):GetAddon("tdInspect")
		local Browser = MeetingHorn:GetClass("UI.Browser")
		local Inspect = tdInspect:GetModule("Inspect")

		local origCreateActivityMenu = Browser.CreateActivityMenu
		Browser.CreateActivityMenu = function(self, activity)
			local r = origCreateActivityMenu(self, activity)
			tinsert(r, 3, {
				text = INSPECT,
				func = function()
					Inspect:Query(nil, activity:GetLeader())
				end,
			})
			return r
		end
	end

	local DataBroker = _G.MeetingHornDataBroker
	if DataBroker then
		DataBroker:DisableDrawLayer("BACKGROUND")
		DataBroker:SetSize(110, 12)
		DataBroker:CreateBackdrop("Transparent")
		DataBroker.Text:SetPoint("CENTER", 10, 0)
		DataBroker.backdrop:SetBackdropColor(0, 0, 0, 0.6)
		DataBroker.backdrop:SetBackdropBorderColor(1, 1, 1, 0.2)

		local logo = DataBroker:CreateTexture(nil, "ARTWORK")
		logo:SetTexture("Interface\\AddOns\\MeetingHorn\\Media\\Logo2")
		logo:SetSize(18, 18)
		logo:SetPoint("LEFT", 2, 0)
	end

	T.SkinEditBox(mainFrame.Options.Filters.FilterInputBox.Input, 140, 20)
	mainFrame.Options.Filters.FilterInputBox:StripTextures()
	mainFrame.Options.Filters.FilterInputBox:SetTemplate("Transparent")
	T.SkinCloseButton(mainFrame.CloseButton)

	local w, h = mainFrame.Manage.Creator.CreateButton:GetSize()
	mainFrame.Manage.Creator.CreateButton:SetSize(w, h - 4)

	w, h = mainFrame.Manage.Creator.RecruitButton:GetSize()
	mainFrame.Manage.Creator.RecruitButton:SetSize(w, h - 4)

	w, h = mainFrame.Manage.Creator.CloseButton:GetSize()
	mainFrame.Manage.Creator.CloseButton:SetSize(w, h - 4)

	w, h = mainFrame.Recent.Invite:GetSize()
	mainFrame.Recent.Invite:SetSize(w, h - 4)

	local relF, parent, relT, x, y = mainFrame.Recent.Invite:GetPoint()
	mainFrame.Recent.Invite:SetPoint(relF, parent, relT, x, y - 4)

	w, h = mainFrame.Options.Filters.Add:GetSize()
	mainFrame.Options.Filters.Add:SetSize(w, h - 4)

	w, h = mainFrame.Options.Filters.Import:GetSize()
	mainFrame.Options.Filters.Import:SetSize(w, h - 4)

	w, h = mainFrame.Options.Filters.Export:GetSize()
	mainFrame.Options.Filters.Export:SetSize(w, h - 4)

	relF, parent, relT, x, y = mainFrame.Options.Filters.Add:GetPoint()
	mainFrame.Options.Filters.Add:SetPoint(relF, parent, relT, x, y - 4)

	relF, parent, relT, x, y = mainFrame.Options.Filters.Import:GetPoint()
	mainFrame.Options.Filters.Import:SetPoint(relF, parent, relT, x + 2, y)

	relF, parent, relT, x, y = mainFrame.Options.Filters.Export:GetPoint()
	mainFrame.Options.Filters.Export:SetPoint(relF, parent, relT, x + 2, y)

	relF, parent, relT, x, y = mainFrame.Manage.Chat.ChatBg:GetPoint()
	mainFrame.Manage.Chat.ChatBg:SetPoint(relF, parent, relT, x + 6, y)

	relF, parent, relT, x, y = mainFrame.Recent.Right:GetPoint()
	mainFrame.Recent.Right:SetPoint(relF, parent, relT, x + 6, y)

	relF, parent, relT, x, y = mainFrame.GoodLeader.First.Footer:GetPoint()
	mainFrame.GoodLeader.First.Footer:SetPoint(relF, parent, relT, x, y - 6)

	relF, parent, relT, x, y = mainFrame.GoodLeader.First.Inset:GetPoint()
	mainFrame.GoodLeader.First.Inset:SetPoint(relF, parent, relT, x + 6, y)

	relF, parent, relT, x, y = mainFrame.GoodLeader.First.Header.Search:GetPoint()
	mainFrame.GoodLeader.First.Header.Search:SetPoint(relF, parent, relT, x, y + 15)

	relF, parent, relT, x, y = mainFrame.GoodLeader.First.Header.ApplyLeaderBtn:GetPoint()
	mainFrame.GoodLeader.First.Header.ApplyLeaderBtn:SetPoint(relF, parent, relT, x, y - 10)
end